@@ -14,6 +14,7 @@
 #include "Windows/FileDir.h"
 #include "Windows/FileName.h"
 #include "Windows/Defs.h"
+#include "Windows/System.h"
 
 #include "../../IPassword.h"
 #include "../../ICoder.h"
@@ -42,7 +43,8 @@ static const char *kCopyrightString =
 static const int kNumSwitches = 6;
 
 #ifdef _WIN32
-const wchar_t *defaultExt = L".exe";
+static const wchar_t *kDefaultExt = L".exe";
+static const int kDefaultExtLength = 4;
 #endif
 
 namespace NKey {
@@ -331,8 +333,11 @@ int Main2(
   if (global_use_utf16_conversion) g_StdOut << "on";
   else                             g_StdOut << "off";
   g_StdOut << ",HugeFiles=";
-  if (sizeof(off_t) >= 8) g_StdOut << "on)\n";
-  else                    g_StdOut << "off)\n";
+  if (sizeof(off_t) >= 8) g_StdOut << "on,";
+  else                    g_StdOut << "off,";
+  int nbcpu = NWindows::NSystem::GetNumberOfProcessors();
+  if (nbcpu > 1) g_StdOut << nbcpu << " CPUs)\n";
+  else           g_StdOut << nbcpu << " CPU)\n";
  
   UString archiveName = commandStrings.Front();
 
@@ -381,10 +386,10 @@ int Main2(
 
   bool yesToAll = parser[NKey::kYes].ThereIs;
 
-#ifdef _WIN32
-  if (archiveName.Right(4).CompareNoCase(defaultExt) != 0)
-    archiveName += defaultExt;
-#endif
+  #ifdef _WIN32
+  if (archiveName.Right(kDefaultExtLength).CompareNoCase(kDefaultExt) != 0)
+    archiveName += kDefaultExt;
+  #endif
 
   // NExtractMode::EEnum extractMode;
   // bool isExtractGroupCommand = command.IsFromExtractGroup(extractMode);
@@ -459,7 +464,7 @@ int Main2(
       HRESULT result = ListArchives(
           v1, v2,
           wildcardCensorHead, 
-          true, 
+          true, false, 
           passwordEnabled, 
           password);
       if (result != S_OK)
