@@ -25,11 +25,11 @@ static const UString kIllegalFileNameChars = kIllegalWildCardFileNameChars +
 
 static inline bool IsCharDirLimiter(wchar_t c)
 {
-#ifdef _WIN32
-  return (c == kDirDelimiter1 || c == kDirDelimiter2);
-#else
-  return (c == kDirDelimiter2);
-#endif
+  return (
+    #ifdef _WIN32
+    c == kDirDelimiter1 || 
+    #endif
+    c == kDirDelimiter2);
 }
 
 // -----------------------------------------
@@ -208,7 +208,7 @@ bool CItem::CheckPath(const UStringVector &pathParts, bool isFile) const
 int CCensorNode::FindSubNode(const UString &name) const
 {
   for (int i = 0; i < SubNodes.Size(); i++)
-#ifdef ENV_UNIX // Unix Filesystem are case sensitive.
+#ifdef FILESYSTEM_IS_CASE_SENSITIVE // Unix Filesystem are case sensitive.
     if (SubNodes[i].Name.Compare(name) == 0)
 #else
     if (SubNodes[i].Name.CompareNoCase(name) == 0)
@@ -356,10 +356,23 @@ void CCensorNode::AddItem2(bool include, const UString &path, bool recursive)
   AddItem(include, path2, recursive, forFile, forFolder);
 }
 
+void CCensorNode::ExtendExclude(const CCensorNode &fromNodes)
+{
+  ExcludeItems += fromNodes.ExcludeItems;
+  for (int i = 0; i < fromNodes.SubNodes.Size(); i++)
+  {
+    const CCensorNode &node = fromNodes.SubNodes[i];
+    int subNodeIndex = FindSubNode(node.Name);
+    if (subNodeIndex < 0)
+      subNodeIndex = SubNodes.Add(CCensorNode(node.Name, this));
+    SubNodes[subNodeIndex].ExtendExclude(node);
+  }
+}
+
 int CCensor::FindPrefix(const UString &prefix) const
 {
   for (int i = 0; i < Pairs.Size(); i++)
-#ifdef ENV_UNIX // Unix Filesystem are case sensitive.
+#ifdef FILESYSTEM_IS_CASE_SENSITIVE // Unix Filesystem are case sensitive.
     if (Pairs[i].Prefix.Compare(prefix) == 0)
 #else
     if (Pairs[i].Prefix.CompareNoCase(prefix) == 0)
@@ -440,20 +453,18 @@ bool CCensor::CheckPath(const UString &path, bool isFile) const
   return finded;
 }
 
+void CCensor::ExtendExclude()
+{
+  int i;
+  for (i = 0; i < Pairs.Size(); i++)
+    if (Pairs[i].Prefix.IsEmpty())
+      break;
+  if (i == Pairs.Size())
+    return;
+  int index = i;
+  for (i = 0; i < Pairs.Size(); i++)
+    if (index != i)
+      Pairs[i].Head.ExtendExclude(Pairs[index].Head);
 }
 
-bool AreTheFileNamesDirDelimiterEqual(const UString &name1, const UString &name2)
-{
-  if(name1.Length() != name2.Length())
-    return false;
-  for(int i = 0; i < name1.Length(); i++)
-  {
-    wchar_t char1 = name1[i], char2 = name2[i];
-    if (char1 == char2)
-      continue;
-    if (IsCharDirLimiter(char1) && IsCharDirLimiter(char2))
-      continue;
-    return false;
-  }
-  return true;
 }
