@@ -32,7 +32,7 @@ DWORD WINAPI GetFullPathName( LPCSTR name, DWORD len, LPSTR buffer, LPSTR *lastp
 
   DWORD name_len = strlen(name);
 
-  if ((name[0] == '\\') || (name[0] == '/')) {
+  if (name[0] == '/') {
     DWORD ret = name_len+2;
     if (ret >= len) {
       TRACEN((printf("GetFullPathNameA(%s,%d,)=0000 (case 0)\n",name, (int)len)))
@@ -44,7 +44,7 @@ DWORD WINAPI GetFullPathName( LPCSTR name, DWORD len, LPSTR buffer, LPSTR *lastp
     *lastpart=buffer;
     char *ptr=buffer;
     while (*ptr) {
-      if ((*ptr == '/') || (*ptr == '\\'))
+      if (*ptr == '/')
         *lastpart=ptr+1;
       ptr++;
     }
@@ -62,7 +62,7 @@ DWORD WINAPI GetFullPathName( LPCSTR name, DWORD len, LPSTR buffer, LPSTR *lastp
     *lastpart=buffer;
     char *ptr=buffer;
     while (*ptr) {
-      if ((*ptr == '/') || (*ptr == '\\'))
+      if (*ptr == '/')
         *lastpart=ptr+1;
       ptr++;
     }
@@ -103,7 +103,7 @@ DWORD WINAPI GetFullPathName( LPCSTR name, DWORD len, LPSTR buffer, LPSTR *lastp
     *lastpart=buffer + begin_len + 1;
     char *ptr=buffer;
     while (*ptr) {
-      if ((*ptr == '/') || (*ptr == '\\'))
+      if (*ptr == '/')
         *lastpart=ptr+1;
       ptr++;
     }
@@ -283,12 +283,15 @@ bool MySetFileAttributes(LPCTSTR fileName, DWORD fileAttributes)
 
   if (fileAttributes & FILE_ATTRIBUTE_UNIX_EXTENSION) {
      stat_info.st_mode = fileAttributes >> 16;
+#ifdef HAVE_LSTAT
      if (S_ISLNK(stat_info.st_mode)) {
         if ( convert_to_symlink(name) != 0) {
           TRACEN((printf("MySetFileAttributes(%s,%d) : false-3\n",name,fileAttributes)))
           return false;
         }
-     } else if (S_ISREG(stat_info.st_mode)) {
+     } else
+#endif
+     if (S_ISREG(stat_info.st_mode)) {
        chmod(name,stat_info.st_mode);
      } else if (S_ISDIR(stat_info.st_mode)) {
        // user/7za must be able to create files in this directory
@@ -550,6 +553,7 @@ bool MyGetFullPathName(LPCWSTR fileName, UString &path)
 }
 #endif
 
+#if 0 // FIXED - USELESS
 bool GetOnlyName(LPCTSTR fileName, CSysString &resultName)
 {
   int index;
@@ -570,6 +574,7 @@ bool GetOnlyName(LPCWSTR fileName, UString &resultName)
 }
 #endif
 
+
 bool GetOnlyDirPrefix(LPCTSTR fileName, CSysString &resultName)
 {
   int index;
@@ -590,6 +595,8 @@ bool GetOnlyDirPrefix(LPCWSTR fileName, UString &resultName)
 }
 #endif
 
+#endif // #if 0 - USELESS
+
 #endif
 
 
